# -*- coding: utf-8 -*-
from setuphelpers import *
import os
import sys

libdev_dir = os.sep.join([sys.executable.rsplit(os.path.sep, 1)[0].replace("/bin", ""), "libdev"])
libdev_sp_dir = os.sep.join([sys.executable.rsplit(os.path.sep, 1)[0].replace("/bin", ""), "libdev", "site-packages"])
sys.path.insert(0, libdev_dir)
sys.path.insert(0, libdev_sp_dir)


package_name = "black"
install_in_libdev = False  # False with lib generating bins and if any dependencies are present in "lib", then remove them from requirements.txt


def install():
    source_path = makepath(basedir, package_name)
    mkdirs(libdev_sp_dir)
    if isfile("requirements.txt"):
        pip_install_cmd = f'"{get_waptpython_path()}" -m pip install -r requirements.txt --upgrade --no-deps'
    else:
        pip_install_cmd = f'"{get_waptpython_path()}" -m pip install {package_name} --upgrade --no-deps'  # =={control.get_software_version()}
    pip_install_cmd += f' --no-index --find-links "{source_path}"'
    if install_in_libdev:
        pip_install_cmd += f' --target "{libdev_sp_dir}"'
    if force:
        pip_install_cmd += " --force-reinstall"
    print(run(pip_install_cmd))


def audit():
    audit_status = "OK"
    audit_pip_package = str(run(f'"{get_waptpython_path()}" -m pip show {package_name}', accept_returncodes=[0, 1, 3010]))
    print(audit_pip_package)
    if "not found" in audit_pip_package:
        print(f"Reinstalling: {control.package}")
        WAPT.install(control.package, force=True)
        audit_status = "WARNING"
    return audit_status


def uninstall():
    pip_uninstall_cmd = f'"{get_waptpython_path()}" -m pip uninstall {package_name} -y'
    print(run(pip_uninstall_cmd))

    for lib_dir in glob.glob(f"{libdev_sp_dir}/{package_name}*/"):
        remove_tree(lib_dir)


def get_waptpython_path():
    if get_os_name() == "Windows":
        return makepath(WAPT.wapt_base_dir, "waptpython.exe")
    else:
        return makepath(WAPT.wapt_base_dir, "waptpython.sh")
